pub struct BitString { /* private fields */ }Implementations
Sourceimpl BitString
impl BitString
Sourcepub fn as_words(&self) -> &[u64]
pub fn as_words(&self) -> &[u64]
Returns the internal little-endian words.
Bit index i is stored in word i / 64, bit offset i % 64.
Unused high bits in the last word are guaranteed to be zero.
pub fn first(&self) -> Option<bool>
pub fn last(&self) -> Option<bool>
pub fn to_bool_vec(&self) -> Vec<bool>
Sourceimpl BitString
impl BitString
pub fn and_bits(&self, rhs: &Self) -> Result<Self, BitStringLenMismatch>
pub fn or_bits(&self, rhs: &Self) -> Result<Self, BitStringLenMismatch>
pub fn xor_bits(&self, rhs: &Self) -> Result<Self, BitStringLenMismatch>
pub fn not_bits(&self) -> Self
pub fn count_ones(&self) -> usize
pub fn count_zeros(&self) -> usize
pub fn shl_zeros(&self, amount: usize) -> Self
pub fn shr_zeros(&self, amount: usize) -> Self
Sourceimpl BitString
impl BitString
pub fn new() -> Self
pub fn repeat(value: bool, len: usize) -> Self
pub fn zeros(len: usize) -> Self
pub fn ones(len: usize) -> Self
Sourcepub fn from_words(words: &[u64], len: usize) -> Option<Self>
pub fn from_words(words: &[u64], len: usize) -> Option<Self>
Constructs a bit string from packed little-endian words.
The input must contain exactly enough words for len.
Unused high bits in the last word are masked out.
Sourceimpl BitString
impl BitString
pub fn set(&mut self, index: usize, value: bool) -> Option<bool>
pub fn push(&mut self, value: bool)
pub fn pop(&mut self) -> Option<bool>
pub fn truncate(&mut self, len: usize)
pub fn clear(&mut self)
pub fn insert(&mut self, index: usize, value: bool)
pub fn remove(&mut self, index: usize) -> bool
pub fn push_bits(&mut self, rhs: &Self)
pub fn insert_bits(&mut self, index: usize, rhs: &Self)
pub fn split_off(&mut self, at: usize) -> Self
pub fn replace_interval(&mut self, interval: UsizeCO, replacement: &Self)
pub fn drain_interval(&mut self, interval: UsizeCO) -> Self
pub fn retain<F>(&mut self, f: F)
Sourceimpl BitString
impl BitString
pub fn slice(&self, interval: UsizeCO) -> Self
pub fn slice_from(&self, start: usize) -> Self
pub fn slice_until(&self, end: usize) -> Self
Sourceimpl BitString
impl BitString
pub fn matches_at(&self, index: usize, pattern: &Self) -> bool
pub fn starts_with(&self, prefix: &Self) -> bool
pub fn ends_with(&self, suffix: &Self) -> bool
pub fn contains_bits(&self, needle: &Self) -> bool
pub fn find_bits(&self, needle: &Self) -> Option<usize>
pub fn rfind_bits(&self, needle: &Self) -> Option<usize>
pub fn strip_prefix(&self, prefix: &Self) -> Option<Self>
pub fn strip_suffix(&self, suffix: &Self) -> Option<Self>